gemini

package
v0.9.0-alpha.3 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 12, 2026 License: Apache-2.0 Imports: 1 Imported by: 0

Documentation

Overview

Package gemini defines the extension for gemini.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type GroundingChunk

type GroundingChunk struct {
	// Grounding chunk from the web.
	Web *GroundingChunkWeb `json:"web,omitempty"`
}

type GroundingChunkWeb

type GroundingChunkWeb struct {
	// Domain of the (original) URI. This field is not supported in Gemini API.
	Domain string `json:"domain,omitempty"`
	// Title of the chunk.
	Title string `json:"title,omitempty"`
	// URI reference of the chunk.
	URI string `json:"uri,omitempty"`
}

GroundingChunkWeb is the chunk from the web.

type GroundingMetadata

type GroundingMetadata struct {
	// List of supporting references retrieved from specified grounding source.
	GroundingChunks []*GroundingChunk `json:"grounding_chunks,omitempty"`
	// Optional. List of grounding support.
	GroundingSupports []*GroundingSupport `json:"grounding_supports,omitempty"`
	// Optional. Google search entry for the following-up web searches.
	SearchEntryPoint *SearchEntryPoint `json:"search_entry_point,omitempty"`
	// Optional. Web search queries for the following-up web search.
	WebSearchQueries []string `json:"web_search_queries,omitempty"`
}

type GroundingSupport

type GroundingSupport struct {
	// Confidence score of the support references. Ranges from 0 to 1. 1 is the most confident.
	// For Gemini 2.0 and before, this list must have the same size as the grounding_chunk_indices.
	// For Gemini 2.5 and after, this list will be empty and should be ignored.
	ConfidenceScores []float32 `json:"confidence_scores,omitempty"`
	// A list of indices (into 'grounding_chunk') specifying the citations associated with
	// the claim. For instance [1,3,4] means that grounding_chunk[1], grounding_chunk[3],
	// grounding_chunk[4] are the retrieved content attributed to the claim.
	GroundingChunkIndices []int `json:"grounding_chunk_indices,omitempty"`
	// Segment of the content this support belongs to.
	Segment *Segment `json:"segment,omitempty"`
}

type ResponseMetaExtension

type ResponseMetaExtension struct {
	ID            string             `json:"id,omitempty"`
	FinishReason  string             `json:"finish_reason,omitempty"`
	GroundingMeta *GroundingMetadata `json:"grounding_meta,omitempty"`
}

func ConcatResponseMetaExtensions

func ConcatResponseMetaExtensions(chunks []*ResponseMetaExtension) (*ResponseMetaExtension, error)

ConcatResponseMetaExtensions concatenates multiple ResponseMetaExtension chunks into a single one.

type SearchEntryPoint

type SearchEntryPoint struct {
	// Optional. Web content snippet that can be embedded in a web page or an app webview.
	RenderedContent string `json:"rendered_content,omitempty"`
	// Optional. Base64 encoded JSON representing array of tuple.
	SDKBlob []byte `json:"sdk_blob,omitempty"`
}

SearchEntryPoint is the Google search entry point.

type Segment

type Segment struct {
	// Output only. End index in the given Part, measured in bytes. Offset from the start
	// of the Part, exclusive, starting at zero.
	EndIndex int `json:"end_index,omitempty"`
	// Output only. The index of a Part object within its parent Content object.
	PartIndex int `json:"part_index,omitempty"`
	// Output only. Start index in the given Part, measured in bytes. Offset from the start
	// of the Part, inclusive, starting at zero.
	StartIndex int `json:"start_index,omitempty"`
	// Output only. The text corresponding to the segment from the response.
	Text string `json:"text,omitempty"`
}

Segment of the content.

Jump to